@@ -1,3 +1,5 @@
+from __future__ import division, absolute_import, unicode_literals
+
 __all__ = ('decorator', 'memoize', 'interruptable')
 
 import errno
@@ -17,11 +19,13 @@ def decorator(caller, func=None):
             def _caller(*args, **opts):
                 return caller(f, *args, **opts)
             return _caller
+        _decorator.func = func
         return _decorator
     else:
         # return a decorated function
         def _decorated(*args, **opts):
             return caller(func, *args, **opts)
+        _decorated.func = func
         return _decorated
 
 
@@ -65,11 +69,11 @@ def interruptable(func, *args, **opts):
     while True:
         try:
             result = func(*args, **opts)
-        except IOError, e:
+        except IOError as e:
             if e.errno == errno.EINTR:
                 continue
             raise e
-        except OSError, e:
+        except OSError as e:
             if e.errno in (errno.EINTR, errno.EINVAL):
                 continue
             raise e
