@@ -1,4 +1,5 @@
 """i18n and l10n support for git-cola"""
+from __future__ import division, absolute_import, unicode_literals
 
 import gettext as _gettext
 import os
@@ -9,6 +10,10 @@ from cola import core
 from cola import resources
 
 _null_translation = _gettext.NullTranslations()
+# Python 3 compat
+if not hasattr(_null_translation, 'ugettext'):
+    _null_translation.ugettext = _null_translation.gettext
+    _null_translation.ungettext = _null_translation.ngettext
 _translation = _null_translation
 
 
@@ -32,6 +37,7 @@ def install(locale):
     if sys.platform == 'win32':
         _check_win32_locale()
     if locale:
+        compat.setenv('LANGUAGE', locale)
         compat.setenv('LANG', locale)
         compat.setenv('LC_MESSAGES', locale)
     _install_custom_language()
@@ -39,6 +45,10 @@ def install(locale):
     _translation = _gettext.translation('git-cola',
                                         localedir=_get_locale_dir(),
                                         fallback=True)
+    # Python 3 compat
+    if not hasattr(_translation, 'ugettext'):
+        _translation.ugettext = _translation.gettext
+        _translation.ungettext = _translation.ngettext
 
 def uninstall():
     global _translation
