@@ -1,7 +1,6 @@
 from __future__ import division, absolute_import, unicode_literals
 
 import os
-import subprocess
 from cola import core
 from cola.i18n import N_
 
@@ -55,9 +54,10 @@ class Interaction(object):
 
     @classmethod
     def run_command(cls, title, cmd):
-        cls.log('$ ' + subprocess.list2cmdline(cmd))
+        cls.log('$ ' + core.list2cmdline(cmd))
         status, out, err = core.run_command(cmd)
         cls.log_status(status, out, err)
+        return status, out, err
 
     @classmethod
     def confirm_config_action(cls, name, opts):
@@ -79,3 +79,5 @@ class Interaction(object):
     def log(cls, message):
         if cls.VERBOSE:
             core.stdout(message)
+
+    safe_log = log
