@@ -234,6 +234,7 @@ def word_wrap(text, tabwidth, limit):
             r'Backtraced-by|'
             r'Helped-by|'
             r'Liked-by|'
+            r'Link|'
             r'Improved-by|'
             r'Inspired-by|'
             r'Initial-patch-by|'
@@ -243,9 +244,12 @@ def word_wrap(text, tabwidth, limit):
             r'Mentored-by|'
             r'Patch-by|'
             r'Proposed-by|'
+            r'References|'
+            r'Related-to|'
             r'Reported-by|'
             r'Requested-by|'
             r'Reviewed-by|'
+            r'See-also|'
             r'Signed-off-by|'
             r'Signed-Off-by|'
             r'Spotted-by|'
