@@ -3,14 +3,17 @@ from __future__ import division, absolute_import, unicode_literals
 from PyQt4 import QtGui
 from PyQt4.QtCore import SIGNAL
 
+from cola import cmds
+from cola import hotkeys
+from cola import qtutils
 from cola.i18n import N_
 from cola.git import git
-from cola import qtutils
 from cola.widgets.standard import TreeWidget
 from cola.widgets.diff import COMMITS_SELECTED
 from cola.widgets.diff import FILES_SELECTED
 
 HISTORIES_SELECTED = 'HISTORIES_SELECTED'
+DIFFTOOL_SELECTED = 'DIFFTOOL_SELECTED'
 
 class FileWidget(TreeWidget):
 
@@ -20,13 +23,25 @@ class FileWidget(TreeWidget):
         self.setHeaderLabels([N_('Filename'), N_('Additions'), N_('Deletions')])
         notifier.add_observer(COMMITS_SELECTED, self.commits_selected)
 
+        self.show_history_action = (
+                qtutils.add_action(self, N_('Show History'),
+                                   self.show_file_history, hotkeys.HISTORY))
+
+        self.launch_difftool_action = (
+                qtutils.add_action(self, N_('Launch Diff Tool'),
+                                   self.show_file_diff, hotkeys.DIFF))
+
+        self.launch_editor_action = (
+                qtutils.add_action(self, N_('Launch Diff Tool'),
+                                   self.edit_paths, hotkeys.EDIT))
+
         self.connect(self, SIGNAL('itemSelectionChanged()'),
                      self.selection_changed)
 
     def selection_changed(self):
         items = self.selected_items()
         self.notifier.notify_observers(FILES_SELECTED,
-                                       [i.file_name for i in items])
+                                       [i.path for i in items])
 
     def commits_selected(self, commits):
         if not commits:
@@ -69,21 +84,30 @@ class FileWidget(TreeWidget):
 
     def contextMenuEvent(self, event):
         menu = QtGui.QMenu(self)
-        menu.addAction(qtutils.add_action(self, N_('Show history'),
-                               self.show_file_history))
+        menu.addAction(self.show_history_action)
+        menu.addAction(self.launch_difftool_action)
         menu.exec_(self.mapToGlobal(event.pos()))
 
+    def show_file_diff(self):
+        self.notifier.notify_observers(DIFFTOOL_SELECTED, self.selected_paths())
+
+    def selected_paths(self):
+        return [i.path for i in self.selected_items()]
+
+    def edit_paths(self):
+        cmds.do(cmds.Edit, self.selected_paths())
+
     def show_file_history(self):
         items = self.selected_items()
         self.notifier.notify_observers(HISTORIES_SELECTED,
-                                       [i.file_name for i in items])
+                                       [i.path for i in items])
 
 class FileTreeWidgetItem(QtGui.QTreeWidgetItem):
 
     def __init__(self, file_log, parent=None):
         QtGui.QTreeWidgetItem.__init__(self, parent)
         texts = file_log.split('\t')
-        self.file_name = texts[2]
-        self.setText(0, self.file_name) # file name
-        self.setText(1, texts[0]) # addition
-        self.setText(2, texts[1]) # deletion
+        self.path = path = texts[2]
+        self.setText(0, path)
+        self.setText(1, texts[0])
+        self.setText(2, texts[1])
