@@ -3,10 +3,12 @@ from __future__ import division, absolute_import, unicode_literals
 import time
 
 from PyQt4 import QtGui
+from PyQt4.QtCore import SIGNAL
 
 from cola.i18n import N_
 from cola.widgets import defs
 from cola.widgets.text import MonoTextView
+from cola import qtutils
 
 
 class LogWidget(QtGui.QWidget):
@@ -14,13 +16,13 @@ class LogWidget(QtGui.QWidget):
     def __init__(self, parent=None, output=None):
         QtGui.QWidget.__init__(self, parent)
 
-        self._layout = QtGui.QVBoxLayout(self)
-        self._layout.setMargin(defs.no_margin)
-
         self.output_text = MonoTextView(self)
-        self._layout.addWidget(self.output_text)
         if output:
             self.set_output(output)
+        self.main_layout = qtutils.vbox(defs.no_margin, defs.spacing,
+                                        self.output_text)
+        self.setLayout(self.main_layout)
+        self.connect(self, SIGNAL('log'), self.log)
 
     def clear(self):
         self.output_text.clear()
@@ -50,3 +52,8 @@ class LogWidget(QtGui.QWidget):
         cursor.insertText('\n')
         cursor.movePosition(cursor.End)
         text.setTextCursor(cursor)
+
+    def safe_log(self, msg):
+        """A version of the log() method that can be called from other
+        threads."""
+        self.emit(SIGNAL('log'), msg)
