@@ -7,6 +7,8 @@ from PyQt4.QtCore import SIGNAL
 
 from cola import cmds
 from cola import gitcmds
+from cola import hotkeys
+from cola import icons
 from cola import qtutils
 from cola.i18n import N_
 from cola.widgets import defs
@@ -51,31 +53,20 @@ class RecentFileDialog(standard.Dialog):
         self.count_label = QtGui.QLabel()
         self.count_label.setText(N_('Showing changes since'))
 
-        self.refresh_button = QtGui.QPushButton()
-        self.refresh_button.setText(N_('Refresh'))
-        self.refresh_button.setIcon(qtutils.reload_icon())
-        self.refresh_button.setEnabled(False)
+        self.refresh_button = qtutils.refresh_button(enabled=False)
 
         self.tree = GitTreeWidget(parent=self)
         self.tree_model = GitFileTreeModel(self)
         self.tree.setModel(self.tree_model)
 
-        self.expand_button = QtGui.QPushButton()
-        self.expand_button.setText(N_('Expand all'))
-        self.expand_button.setIcon(qtutils.open_icon())
+        self.expand_button = qtutils.create_button(text=N_('Expand all'),
+                                                   icon=icons.unfold())
 
-        self.collapse_button = QtGui.QPushButton()
-        self.collapse_button.setText(N_('Collapse all'))
-        self.collapse_button.setIcon(qtutils.dir_close_icon())
+        self.collapse_button = qtutils.create_button(text=N_('Collapse all'),
+                                                     icon=icons.fold())
 
-        self.edit_button = QtGui.QPushButton()
-        self.edit_button.setText(N_('Edit'))
-        self.edit_button.setIcon(qtutils.apply_icon())
-        self.edit_button.setDefault(True)
-        self.edit_button.setEnabled(False)
-
-        self.close_button = QtGui.QPushButton()
-        self.close_button.setText(N_('Close'))
+        self.edit_button = qtutils.edit_button(enabled=False, default=True)
+        self.close_button = qtutils.close_button()
 
         self.top_layout = qtutils.hbox(defs.no_margin, defs.spacing,
                                        self.count_label, self.count,
@@ -112,7 +103,7 @@ class RecentFileDialog(standard.Dialog):
         qtutils.connect_button(self.close_button, self.accept)
         qtutils.connect_button(self.edit_button, self.edit_selected)
 
-        qtutils.add_action(self, N_('Refresh'), self.refresh, 'Ctrl+R')
+        qtutils.add_action(self, N_('Refresh'), self.refresh, hotkeys.REFRESH)
 
         self.update_thread.start()
 
