@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+from __future__ import division, absolute_import, unicode_literals
 
 __copyright__ = """
 2012, Peter Norvig (http://norvig.com/spell-correct.html)
@@ -21,9 +22,9 @@ from PyQt4.Qt import QTextCursor
 from PyQt4.Qt import Qt
 from PyQt4.QtCore import SIGNAL
 
-from cola.compat import set
 from cola.i18n import N_
 from cola.widgets.text import HintedTextEdit
+from cola.compat import ustr
 
 
 alphabet = 'abcdefghijklmnopqrstuvwxyz'
@@ -36,12 +37,12 @@ def train(features, model):
 
 
 def edits1(word):
-   splits     = [(word[:i], word[i:]) for i in range(len(word) + 1)]
-   deletes    = [a + b[1:] for a, b in splits if b]
-   transposes = [a + b[1] + b[0] + b[2:] for a, b in splits if len(b)>1]
-   replaces   = [a + c + b[1:] for a, b in splits for c in alphabet if b]
-   inserts    = [a + c + b     for a, b in splits for c in alphabet]
-   return set(deletes + transposes + replaces + inserts)
+    splits     = [(word[:i], word[i:]) for i in range(len(word) + 1)]
+    deletes    = [a + b[1:] for a, b in splits if b]
+    transposes = [a + b[1] + b[0] + b[2:] for a, b in splits if len(b)>1]
+    replaces   = [a + c + b[1:] for a, b in splits for c in alphabet if b]
+    inserts    = [a + c + b     for a, b in splits for c in alphabet]
+    return set(deletes + transposes + replaces + inserts)
 
 
 def known_edits2(word, words):
@@ -134,12 +135,13 @@ class SpellCheckTextEdit(HintedTextEdit):
         # suggestions if it is.
         spell_menu = None
         if self.textCursor().hasSelection():
-            text = unicode(self.textCursor().selectedText())
+            text = ustr(self.textCursor().selectedText())
             if not self.spellcheck.check(text):
                 spell_menu = QMenu(N_('Spelling Suggestions'))
                 for word in self.spellcheck.suggest(text):
                     action = SpellAction(word, spell_menu)
-                    self.connect(action, SIGNAL('correct'), self.correct)
+                    self.connect(action, SIGNAL('correct(PyQt_PyObject)'),
+                                 self.correct)
                     spell_menu.addAction(action)
                 # Only add the spelling suggests to the menu if there are
                 # suggestions.
@@ -150,7 +152,7 @@ class SpellCheckTextEdit(HintedTextEdit):
         return popup_menu, spell_menu
 
     def contextMenuEvent(self, event):
-        popup_menu = self.context_menu()
+        popup_menu, _spell_menu = self.context_menu()
         popup_menu.exec_(self.mapToGlobal(event.pos()))
 
     def correct(self, word):
@@ -166,7 +168,7 @@ class SpellCheckTextEdit(HintedTextEdit):
 
 class Highlighter(QSyntaxHighlighter):
 
-    WORDS = "(?iu)[\w']+"
+    WORDS = r"(?iu)[\w']+"
 
     def __init__(self, doc, spellcheck):
         QSyntaxHighlighter.__init__(self, doc)
@@ -180,7 +182,7 @@ class Highlighter(QSyntaxHighlighter):
     def highlightBlock(self, text):
         if not self.enabled:
             return
-        text = unicode(text)
+        text = ustr(text)
         fmt = QTextCharFormat()
         fmt.setUnderlineColor(Qt.red)
         fmt.setUnderlineStyle(QTextCharFormat.SpellCheckUnderline)
@@ -200,7 +202,7 @@ class SpellAction(QAction):
         self.connect(self, SIGNAL('triggered()'), self.correct)
 
     def correct(self):
-        self.emit(SIGNAL('correct'), unicode(self.text()))
+        self.emit(SIGNAL('correct(PyQt_PyObject)'), ustr(self.text()))
 
 
 def main(args=sys.argv):
