@@ -9,10 +9,13 @@ from PyQt4.QtCore import SIGNAL
 
 from cola import cmds
 from cola import core
+from cola import hotkeys
+from cola import icons
 from cola import qtutils
 from cola import utils
 from cola.i18n import N_
 from cola.models import main
+from cola.models import prefs
 from cola.models import selection
 from cola.widgets import completion
 from cola.widgets import defs
@@ -30,10 +33,9 @@ class StatusWidget(QtGui.QWidget):
         QtGui.QWidget.__init__(self, parent)
 
         tooltip = N_('Toggle the paths filter')
-        self.filter_button = qtutils.create_action_button(
-                tooltip=tooltip,
-                icon=qtutils.filter_icon())
-
+        icon = icons.ellipsis()
+        self.filter_button = qtutils.create_action_button(tooltip=tooltip,
+                                                          icon=icon)
         self.filter_widget = StatusFilterWidget()
         self.filter_widget.hide()
         self.tree = StatusTreeWidget()
@@ -44,7 +46,8 @@ class StatusWidget(QtGui.QWidget):
         self.setLayout(self.main_layout)
 
         self.toggle_action = qtutils.add_action(self, tooltip,
-                self.toggle_filter, 'Ctrl+Shift+F')
+                                                self.toggle_filter,
+                                                hotkeys.FILTER)
 
         titlebar.add_corner_widget(self.filter_button)
         qtutils.connect_button(self.filter_button, self.toggle_filter)
@@ -103,92 +106,95 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         self.setRootIsDecorated(False)
         self.setIndentation(0)
         self.setDragEnabled(True)
+        self.setAutoScroll(False)
 
-        self.add_item(N_('Staged'), hide=True)
-        self.add_item(N_('Unmerged'), hide=True)
-        self.add_item(N_('Modified'), hide=True)
-        self.add_item(N_('Untracked'), hide=True)
+        ok = icons.ok()
+        compare = icons.compare()
+        question = icons.question()
+        self.add_toplevel_item(N_('Staged'), ok, hide=True)
+        self.add_toplevel_item(N_('Unmerged'), compare, hide=True)
+        self.add_toplevel_item(N_('Modified'), compare, hide=True)
+        self.add_toplevel_item(N_('Untracked'), question, hide=True)
 
         # Used to restore the selection
-        self.old_scroll = None
+        self.old_vscroll = None
+        self.old_hscroll = None
         self.old_selection = None
         self.old_contents = None
         self.old_current_item = None
         self.expanded_items = set()
 
-        self.process_selection_action = qtutils.add_action(self,
-                cmds.StageOrUnstage.name(),
-                cmds.run(cmds.StageOrUnstage),
-                cmds.StageOrUnstage.SHORTCUT)
+        self.process_selection_action = qtutils.add_action(
+            self, cmds.StageOrUnstage.name(),
+            cmds.run(cmds.StageOrUnstage), hotkeys.STAGE_SELECTION)
 
-        self.revert_unstaged_edits_action = qtutils.add_action(self,
-                cmds.RevertUnstagedEdits.name(),
-                cmds.run(cmds.RevertUnstagedEdits),
-                cmds.RevertUnstagedEdits.SHORTCUT)
-        self.revert_unstaged_edits_action.setIcon(qtutils.theme_icon('edit-undo.svg'))
+        self.revert_unstaged_edits_action = qtutils.add_action(
+            self, cmds.RevertUnstagedEdits.name(),
+            cmds.run(cmds.RevertUnstagedEdits), hotkeys.REVERT)
+        self.revert_unstaged_edits_action.setIcon(icons.undo())
 
-        self.launch_difftool_action = qtutils.add_action(self,
-                cmds.LaunchDifftool.name(),
-                cmds.run(cmds.LaunchDifftool),
-                cmds.LaunchDifftool.SHORTCUT)
-        self.launch_difftool_action.setIcon(qtutils.git_icon())
+        self.launch_difftool_action = qtutils.add_action(
+            self, cmds.LaunchDifftool.name(),
+            cmds.run(cmds.LaunchDifftool), hotkeys.DIFF)
+        self.launch_difftool_action.setIcon(icons.diff())
 
-        self.launch_editor_action = qtutils.add_action(self,
-                cmds.LaunchEditor.name(),
-                cmds.run(cmds.LaunchEditor),
-                cmds.LaunchEditor.SHORTCUT,
-                'Return', 'Enter')
-        self.launch_editor_action.setIcon(qtutils.options_icon())
+        self.launch_editor_action = qtutils.add_action(
+            self, cmds.LaunchEditor.name(),
+            cmds.run(cmds.LaunchEditor), hotkeys.EDIT, *hotkeys.ACCEPT)
+        self.launch_editor_action.setIcon(icons.edit())
 
         if not utils.is_win32():
-            self.open_using_default_app = qtutils.add_action(self,
-                    cmds.OpenDefaultApp.name(),
-                    self._open_using_default_app,
-                    cmds.OpenDefaultApp.SHORTCUT)
-            self.open_using_default_app.setIcon(qtutils.file_icon())
+            self.open_using_default_app = qtutils.add_action(
+                self, cmds.OpenDefaultApp.name(),
+                self._open_using_default_app, hotkeys.PRIMARY_ACTION)
+            self.open_using_default_app.setIcon(icons.default_app())
 
-            self.open_parent_dir_action = qtutils.add_action(self,
-                    cmds.OpenParentDir.name(),
-                    self._open_parent_dir,
-                    cmds.OpenParentDir.SHORTCUT)
-            self.open_parent_dir_action.setIcon(qtutils.open_file_icon())
+            self.open_parent_dir_action = qtutils.add_action(
+                self, cmds.OpenParentDir.name(),
+                self._open_parent_dir, hotkeys.SECONDARY_ACTION)
+            self.open_parent_dir_action.setIcon(icons.folder())
 
-        self.up_action = qtutils.add_action(self,
-                N_('Move Up'), self.move_up,
-                Qt.Key_K, Qt.AltModifier + Qt.Key_K)
+        self.up_action = qtutils.add_action(
+            self, N_('Move Up'), self.move_up,
+            hotkeys.MOVE_UP, hotkeys.MOVE_UP_SECONDARY)
 
-        self.down_action = qtutils.add_action(self,
-                N_('Move Down'), self.move_down,
-                Qt.Key_J, Qt.AltModifier + Qt.Key_J)
+        self.down_action = qtutils.add_action(
+            self, N_('Move Down'), self.move_down,
+            hotkeys.MOVE_DOWN, hotkeys.MOVE_DOWN_SECONDARY)
 
-        self.copy_path_action = qtutils.add_action(self,
-                N_('Copy Path to Clipboard'),
-                self.copy_path, QtGui.QKeySequence.Copy)
-        self.copy_path_action.setIcon(qtutils.theme_icon('edit-copy.svg'))
+        self.copy_path_action = qtutils.add_action(
+            self, N_('Copy Path to Clipboard'), self.copy_path, hotkeys.COPY)
+        self.copy_path_action.setIcon(icons.copy())
 
-        self.copy_relpath_action = qtutils.add_action(self,
-                N_('Copy Relative Path to Clipboard'),
-                self.copy_relpath, QtGui.QKeySequence.Cut)
-        self.copy_relpath_action.setIcon(qtutils.theme_icon('edit-copy.svg'))
+        self.copy_relpath_action = qtutils.add_action(
+            self, N_('Copy Relative Path to Clipboard'),
+            self.copy_relpath, hotkeys.CUT)
+        self.copy_relpath_action.setIcon(icons.copy())
+
+        self.view_history_action = qtutils.add_action(
+            self, N_('View History...'), self.view_history, hotkeys.HISTORY)
+
+        self.view_blame_action = qtutils.add_action(
+            self, N_('Blame...'), self.view_blame, hotkeys.BLAME)
 
         # MoveToTrash and Delete use the same shortcut.
         # We will only bind one of them, depending on whether or not the
         # MoveToTrash command is avaialble.  When available, the hotkey
         # is bound to MoveToTrash, otherwise it is bound to Delete.
         if cmds.MoveToTrash.AVAILABLE:
-            self.move_to_trash_action = qtutils.add_action(self,
-                    N_('Move file(s) to trash'),
-                    self._trash_untracked_files, cmds.MoveToTrash.SHORTCUT)
-            self.move_to_trash_action.setIcon(qtutils.discard_icon())
-            delete_shortcut = cmds.Delete.SHORTCUT
+            self.move_to_trash_action = qtutils.add_action(
+                self, N_('Move file(s) to trash'),
+                self._trash_untracked_files, hotkeys.TRASH)
+            self.move_to_trash_action.setIcon(icons.discard())
+            delete_shortcut = hotkeys.DELETE_FILE
         else:
             self.move_to_trash_action = None
-            delete_shortcut = cmds.Delete.ALT_SHORTCUT
+            delete_shortcut = hotkeys.DELETE_FILE_SECONDARY
 
-        self.delete_untracked_files_action = qtutils.add_action(self,
-                N_('Delete File(s)...'),
-                self._delete_untracked_files, delete_shortcut)
-        self.delete_untracked_files_action.setIcon(qtutils.discard_icon())
+        self.delete_untracked_files_action = qtutils.add_action(
+            self, N_('Delete File(s)...'),
+            self._delete_untracked_files, delete_shortcut)
+        self.delete_untracked_files_action.setIcon(icons.discard())
 
         self.connect(self, SIGNAL('about_to_update()'),
                      self._about_to_update, Qt.QueuedConnection)
@@ -212,15 +218,19 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         self.connect(self, SIGNAL('itemExpanded(QTreeWidgetItem*)'),
                      lambda x: self.update_column_widths())
 
-    def add_item(self, txt, hide=False):
-        """Create a new top-level item in the status tree."""
-        # TODO no icon
+    def add_toplevel_item(self, txt, icon, hide=False):
         font = self.font()
-        font.setBold(True)
+        if prefs.bold_headers():
+            font.setBold(True)
+        else:
+            font.setItalic(True)
 
         item = QtGui.QTreeWidgetItem(self)
         item.setFont(0, font)
         item.setText(0, txt)
+        item.setIcon(0, icon)
+        if prefs.bold_headers():
+            item.setBackground(0, self.palette().midlight())
         if hide:
             self.setItemHidden(item, True)
 
@@ -311,11 +321,16 @@ class StatusTreeWidget(QtGui.QTreeWidget):
                         reselect(j, current=True)
                         return
 
-    def restore_scrollbar(self):
+    def restore_scrollbars(self):
         vscroll = self.verticalScrollBar()
-        if vscroll and self.old_scroll is not None:
-            vscroll.setValue(self.old_scroll)
-            self.old_scroll = None
+        if vscroll and self.old_vscroll is not None:
+            vscroll.setValue(self.old_vscroll)
+            self.old_vscroll = None
+
+        hscroll = self.horizontalScrollBar()
+        if hscroll and self.old_hscroll is not None:
+            hscroll.setValue(self.old_hscroll)
+            self.old_hscroll = None
 
     def staged_item(self, itemidx):
         return self._subtree_item(self.idx_staged, itemidx)
@@ -356,15 +371,17 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         self.emit(SIGNAL('about_to_update()'))
 
     def _about_to_update(self):
+        self.save_scrollbars()
         self.save_selection()
-        self.save_scrollbar()
 
-    def save_scrollbar(self):
+    def save_scrollbars(self):
         vscroll = self.verticalScrollBar()
         if vscroll:
-            self.old_scroll = vscroll.value()
-        else:
-            self.old_scroll = None
+            self.old_vscroll = vscroll.value()
+
+        hscroll = self.horizontalScrollBar()
+        if hscroll:
+            self.old_hscroll = hscroll.value()
 
     def current_item(self):
         s = self.selected_indexes()
@@ -395,10 +412,10 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         self.set_modified(self.m.modified)
         self.set_unmerged(self.m.unmerged)
         self.set_untracked(self.m.untracked)
-        self.restore_selection()
-        self.restore_scrollbar()
         self.update_column_widths()
         self.update_actions()
+        self.restore_selection()
+        self.restore_scrollbars()
 
     def update_actions(self, selected=None):
         if selected is None:
@@ -497,28 +514,24 @@ class StatusTreeWidget(QtGui.QTreeWidget):
 
     def _create_header_context_menu(self, menu, idx):
         if idx == self.idx_staged:
-            menu.addAction(qtutils.remove_icon(),
-                           N_('Unstage All'),
+            menu.addAction(icons.remove(), N_('Unstage All'),
                            cmds.run(cmds.UnstageAll))
             return menu
         elif idx == self.idx_unmerged:
-            action = menu.addAction(qtutils.add_icon(),
-                                    cmds.StageUnmerged.name(),
+            action = menu.addAction(icons.add(), cmds.StageUnmerged.name(),
                                     cmds.run(cmds.StageUnmerged))
-            action.setShortcut(cmds.StageUnmerged.SHORTCUT)
+            action.setShortcut(hotkeys.STAGE_SELECTION)
             return menu
         elif idx == self.idx_modified:
-            action = menu.addAction(qtutils.add_icon(),
-                                    cmds.StageModified.name(),
+            action = menu.addAction(icons.add(), cmds.StageModified.name(),
                                     cmds.run(cmds.StageModified))
-            action.setShortcut(cmds.StageModified.SHORTCUT)
+            action.setShortcut(hotkeys.STAGE_SELECTION)
             return menu
 
         elif idx == self.idx_untracked:
-            action = menu.addAction(qtutils.add_icon(),
-                                    cmds.StageUntracked.name(),
+            action = menu.addAction(icons.add(), cmds.StageUntracked.name(),
                                     cmds.run(cmds.StageUntracked))
-            action.setShortcut(cmds.StageUntracked.SHORTCUT)
+            action.setShortcut(hotkeys.STAGE_SELECTION)
             return menu
 
     def _create_staged_context_menu(self, menu, s):
@@ -526,10 +539,9 @@ class StatusTreeWidget(QtGui.QTreeWidget):
             return self._create_staged_submodule_context_menu(menu, s)
 
         if self.m.unstageable():
-            action = menu.addAction(qtutils.remove_icon(),
-                                    N_('Unstage Selected'),
+            action = menu.addAction(icons.remove(), N_('Unstage Selected'),
                                     cmds.run(cmds.Unstage, self.staged()))
-            action.setShortcut(cmds.Unstage.SHORTCUT)
+            action.setShortcut(hotkeys.STAGE_SELECTION)
 
         # Do all of the selected items exist?
         all_exist = all(not i in self.m.staged_deleted and core.exists(i)
@@ -541,15 +553,15 @@ class StatusTreeWidget(QtGui.QTreeWidget):
 
         if all_exist and not utils.is_win32():
             menu.addSeparator()
-            action = menu.addAction(qtutils.file_icon(),
-                    cmds.OpenDefaultApp.name(),
-                    cmds.run(cmds.OpenDefaultApp, self.staged()))
-            action.setShortcut(cmds.OpenDefaultApp.SHORTCUT)
+            open_default = cmds.run(cmds.OpenDefaultApp, self.staged())
+            action = menu.addAction(icons.default_app(),
+                                    cmds.OpenDefaultApp.name(), open_default)
+            action.setShortcut(hotkeys.PRIMARY_ACTION)
 
-            action = menu.addAction(qtutils.open_file_icon(),
-                    cmds.OpenParentDir.name(),
-                    self._open_parent_dir)
-            action.setShortcut(cmds.OpenParentDir.SHORTCUT)
+            action = menu.addAction(icons.folder(),
+                                    cmds.OpenParentDir.name(),
+                                    self._open_parent_dir)
+            action.setShortcut(hotkeys.SECONDARY_ACTION)
 
         if self.m.undoable():
             menu.addSeparator()
@@ -558,52 +570,54 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         menu.addSeparator()
         menu.addAction(self.copy_path_action)
         menu.addAction(self.copy_relpath_action)
+        menu.addAction(self.view_history_action)
+        menu.addAction(self.view_blame_action)
         return menu
 
     def _create_staged_submodule_context_menu(self, menu, s):
-        menu.addAction(qtutils.git_icon(),
-                       N_('Launch git-cola'),
+        menu.addAction(icons.cola(), N_('Launch git-cola'),
                        cmds.run(cmds.OpenRepo,
                                 core.abspath(s.staged[0])))
 
         menu.addAction(self.launch_editor_action)
         menu.addSeparator()
 
-        action = menu.addAction(qtutils.remove_icon(),
-                                N_('Unstage Selected'),
+        action = menu.addAction(icons.remove(), N_('Unstage Selected'),
                                 cmds.run(cmds.Unstage, self.staged()))
-        action.setShortcut(cmds.Unstage.SHORTCUT)
+        action.setShortcut(hotkeys.STAGE_SELECTION)
         menu.addSeparator()
 
         menu.addAction(self.copy_path_action)
         menu.addAction(self.copy_relpath_action)
+        menu.addAction(self.view_history_action)
         return menu
 
     def _create_unmerged_context_menu(self, menu, s):
         menu.addAction(self.launch_difftool_action)
 
-        action = menu.addAction(qtutils.add_icon(),
-                                N_('Stage Selected'),
+        action = menu.addAction(icons.add(), N_('Stage Selected'),
                                 cmds.run(cmds.Stage, self.unstaged()))
-        action.setShortcut(cmds.Stage.SHORTCUT)
+        action.setShortcut(hotkeys.STAGE_SELECTION)
         menu.addSeparator()
         menu.addAction(self.launch_editor_action)
 
         if not utils.is_win32():
             menu.addSeparator()
-            action = menu.addAction(qtutils.file_icon(),
-                    cmds.OpenDefaultApp.name(),
-                    cmds.run(cmds.OpenDefaultApp, self.unmerged()))
-            action.setShortcut(cmds.OpenDefaultApp.SHORTCUT)
+            open_default = cmds.run(cmds.OpenDefaultApp, self.unmerged())
+            action = menu.addAction(icons.default_app(),
+                                    cmds.OpenDefaultApp.name(), open_default)
+            action.setShortcut(hotkeys.PRIMARY_ACTION)
 
-            action = menu.addAction(qtutils.open_file_icon(),
-                    cmds.OpenParentDir.name(),
-                    self._open_parent_dir)
-            action.setShortcut(cmds.OpenParentDir.SHORTCUT)
+            action = menu.addAction(icons.folder(),
+                                    cmds.OpenParentDir.name(),
+                                    self._open_parent_dir)
+            action.setShortcut(hotkeys.SECONDARY_ACTION)
 
         menu.addSeparator()
         menu.addAction(self.copy_path_action)
         menu.addAction(self.copy_relpath_action)
+        menu.addAction(self.view_history_action)
+        menu.addAction(self.view_blame_action)
         return menu
 
     def _create_unstaged_context_menu(self, menu, s):
@@ -613,10 +627,9 @@ class StatusTreeWidget(QtGui.QTreeWidget):
             return self._create_modified_submodule_context_menu(menu, s)
 
         if self.m.stageable():
-            action = menu.addAction(qtutils.add_icon(),
-                                    N_('Stage Selected'),
+            action = menu.addAction(icons.add(), N_('Stage Selected'),
                                     cmds.run(cmds.Stage, self.unstaged()))
-            action.setShortcut(cmds.Stage.SHORTCUT)
+            action.setShortcut(hotkeys.STAGE_SELECTION)
 
         # Do all of the selected items exist?
         all_exist = all(not i in self.m.unstaged_deleted and core.exists(i)
@@ -635,15 +648,15 @@ class StatusTreeWidget(QtGui.QTreeWidget):
 
         if all_exist and self.unstaged() and not utils.is_win32():
             menu.addSeparator()
-            action = menu.addAction(qtutils.file_icon(),
-                    cmds.OpenDefaultApp.name(),
-                    cmds.run(cmds.OpenDefaultApp, self.unstaged()))
-            action.setShortcut(cmds.OpenDefaultApp.SHORTCUT)
+            open_default = cmds.run(cmds.OpenDefaultApp, self.unstaged())
+            action = menu.addAction(icons.default_app(),
+                                    cmds.OpenDefaultApp.name(), open_default)
+            action.setShortcut(hotkeys.PRIMARY_ACTION)
 
-            action = menu.addAction(qtutils.open_file_icon(),
-                    cmds.OpenParentDir.name(),
-                    self._open_parent_dir)
-            action.setShortcut(cmds.OpenParentDir.SHORTCUT)
+            action = menu.addAction(icons.folder(),
+                                    cmds.OpenParentDir.name(),
+                                    self._open_parent_dir)
+            action.setShortcut(hotkeys.SECONDARY_ACTION)
 
         if all_exist and s.untracked:
             menu.addSeparator()
@@ -651,32 +664,34 @@ class StatusTreeWidget(QtGui.QTreeWidget):
                 menu.addAction(self.move_to_trash_action)
             menu.addAction(self.delete_untracked_files_action)
             menu.addSeparator()
-            menu.addAction(qtutils.theme_icon('edit-clear.svg'),
+            menu.addAction(icons.edit(),
                            N_('Add to .gitignore'),
                            cmds.run(cmds.Ignore,
-                                map(lambda x: '/' + x, self.untracked())))
+                                    map(lambda x: '/' + x, self.untracked())))
         menu.addSeparator()
         menu.addAction(self.copy_path_action)
         menu.addAction(self.copy_relpath_action)
+        if not selection.selection_model().is_empty():
+            menu.addAction(self.view_history_action)
+            menu.addAction(self.view_blame_action)
         return menu
 
     def _create_modified_submodule_context_menu(self, menu, s):
-        menu.addAction(qtutils.git_icon(),
-                       N_('Launch git-cola'),
+        menu.addAction(icons.cola(), N_('Launch git-cola'),
                        cmds.run(cmds.OpenRepo, core.abspath(s.modified[0])))
 
         menu.addAction(self.launch_editor_action)
 
         if self.m.stageable():
             menu.addSeparator()
-            action = menu.addAction(qtutils.add_icon(),
-                                    N_('Stage Selected'),
+            action = menu.addAction(icons.add(), N_('Stage Selected'),
                                     cmds.run(cmds.Stage, self.unstaged()))
-            action.setShortcut(cmds.Stage.SHORTCUT)
+            action.setShortcut(hotkeys.STAGE_SELECTION)
 
         menu.addSeparator()
         menu.addAction(self.copy_path_action)
         menu.addAction(self.copy_relpath_action)
+        menu.addAction(self.view_history_action)
         return menu
 
 
@@ -766,7 +781,15 @@ class StatusTreeWidget(QtGui.QTreeWidget):
             idx -= len(content)
 
     def select_item(self, item):
+        # First, scroll to the item, but keep the original hscroll
+        hscroll = None
+        hscrollbar = self.horizontalScrollBar()
+        if hscrollbar:
+            hscroll = hscrollbar.value()
         self.scrollToItem(item)
+        if hscroll is not None:
+            hscrollbar.setValue(hscroll)
+
         self.setCurrentItem(item)
         self.setItemSelected(item, True)
 
@@ -913,14 +936,21 @@ class StatusTreeWidget(QtGui.QTreeWidget):
 
     def mimeData(self, items):
         """Return a list of absolute-path URLs"""
-        paths = qtutils.paths_from_items(items, item_filter=lambda item:
-                                                    not item.deleted
-                                                    and core.exists(item.path))
+        item_filter = lambda item: not item.deleted and core.exists(item.path)
+        paths = qtutils.paths_from_items(items, item_filter=item_filter)
         return qtutils.mimedata_from_paths(paths)
 
     def mimeTypes(self):
         return qtutils.path_mimetypes()
 
+    def view_blame(self):
+        """Signal that we should view blame for paths."""
+        cmds.do(cmds.BlamePaths, selection.union(selection.selection_model()))
+
+    def view_history(self):
+        """Signal that we should view history for paths."""
+        cmds.do(cmds.VisualizePaths, selection.union(selection.selection_model()))
+
 
 class StatusFilterWidget(QtGui.QWidget):
 
