@@ -3,10 +3,10 @@
 from __future__ import unicode_literals
 import unittest
 
-import helper
-
 from cola import core
 
+from test import helper
+
 
 class CoreColaUnicodeTestCase(unittest.TestCase):
     """Tests the cola.core module's unicode handling
