@@ -74,9 +74,9 @@ class GitRepositoryTestCase(TmpPathTestCase):
         self.initialize_repo()
         if commit:
             self.commit_files()
-        git.instance().set_worktree(core.getcwd())
-        gitcfg.instance().reset()
-        gitcmds.clear_cache()
+        git.current().set_worktree(core.getcwd())
+        gitcfg.current().reset()
+        gitcmds.reset()
 
     def git(self, *args):
         p = subprocess.Popen(['git'] + list(args), stdout=subprocess.PIPE,
@@ -87,8 +87,10 @@ class GitRepositoryTestCase(TmpPathTestCase):
 
     def initialize_repo(self):
         self.git('init')
+        self.git('config', '--local', 'user.name', 'Your Name')
+        self.git('config', '--local', 'user.email', 'you@example.com')
         self.touch('A', 'B')
         self.git('add', 'A', 'B')
 
     def commit_files(self):
-        self.git('commit', '-m', 'intitial commit')
+        self.git('commit', '-m', 'initial commit')
